pipi [![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/mehmetkose/pipi/edit/master/README.md)
====

Python dependency install & save tool for pip.

Usage
~~~~~~~~~~~~

::

    pipi package_name

    (almost same as 'pip install package_name && pip freeze > requirements.txt')

Installation
~~~~~~~~~~~~

::

    pip install pipi
